#!/usr/bin/gnuplot

# Spectra with wrong RV are plotted as thick!

set term x11

nm = 1.e-9  # m
ang = 1.e-10/nm  # nm
shift = 0.25
c = 299792458.  # m/s
kms = 1.e3	# m/s
v_rad = +30*kms

set xl "{/Symbol l} [nm]"
set yl "I_{/Symbol l} [] (shifted by 1/4 dataset number)"

set xr [408:416]
set yr [4.50:7.00]
set ytics shift
set mytics 1
set grid ytics mytics
set zeroaxis
set bar 0.5

call "line.plt" "Halpha" 6563
call "line.plt" "Hbeta"  4861
call "line.plt" "Hgamma" 4341
call "line.plt" "Hdelta" 4102
call "line.plt" "HeI"    4009
call "line.plt" "HeI"    4026
call "line.plt" "HeI"    4120
call "line.plt" "HeI"    4143
call "line.plt" "HeI"    4387
call "line.plt" "HeI"    4471
call "line.plt" "HeI"    4713
call "line.plt" "HeI"    4922
call "line.plt" "HeI"    5016
call "line.plt" "HeI"    5047
call "line.plt" "HeI"    5876
call "line.plt" "HeI"    6678
call "line.plt" "CII"    4267
call "line.plt" "MgII"   4481
call "line.plt" "SiII"   4128
call "line.plt" "SiII"   4130
call "line.plt" "SiII"   6347
call "line.plt" "SiII"   6371
call "line.plt" "NeI"    6402
p \
  "synthetic.dat" u ($2/nm):($3+shift*$4)   t "synthetic" w l lt 8,\
  "Spectra.dat"   u ($2/nm):($3+shift*$5):4 t "observed" w err lt 3 pt 1 ps 0,\
  "chi2_SYN.dat"  u ($2/nm):($3+shift*$5)   t "residua"  w l lt 1 lw 1,\
  "<awk '($NF+0>100)' chi2_SYN.dat" u ($2/nm):($3+shift*$5) t "chi^2 > 100" w p lt 1 pt 6 ps 1.5,\
  "<awk '(NF>0) && ($1!=jd){ print; jd=$1; }' chi2_SYN.dat" u ($2/nm):($3+shift*$5):(sprintf("%.1f ", $1-2400000)) w labels not font "Helvetica,12" right,\
  "<awk '($4==14)' synthetic.dat" u ($2/nm):($3+shift*$4)   not w l lt 8 lw 2,\
  "<awk '($4==17)' synthetic.dat" u ($2/nm):($3+shift*$4)   not w l lt 8 lw 2,\
  "<awk '($4==18)' synthetic.dat" u ($2/nm):($3+shift*$4)   not w l lt 8 lw 2,\
  "<awk '($4==19)' synthetic.dat" u ($2/nm):($3+shift*$4)   not w l lt 8 lw 2,\
  "<awk '($4==20)' synthetic.dat" u ($2/nm):($3+shift*$4)   not w l lt 8 lw 2,\
  "<awk '($4==21)' synthetic.dat" u ($2/nm):($3+shift*$4)   not w l lt 8 lw 2,\

pa -1

set term post eps enh color solid
set out "chi2_SYN_LABELS3.eps"
rep

q
  "<awk '($4==14)' synthetic.dat" u ($2/nm*(1.-v_rad /c)):($3+shift*$4)   not w l lt 7 lw 1,\
  "<awk '($4==17)' synthetic.dat" u ($2/nm*(1.-v_rad /c)):($3+shift*$4)   not w l lt 7 lw 1,\
  "<awk '($4==18)' synthetic.dat" u ($2/nm*(1.-40*kms/c)):($3+shift*$4)   not w l lt 7 lw 1,\
  "<awk '($4==19)' synthetic.dat" u ($2/nm*(1.-40*kms/c)):($3+shift*$4)   not w l lt 7 lw 1

  "<awk '($NF+0>100)' chi2_VIS.dat" u (sqrt($2**2+$3**2)/$4):($5+$7) t "chi^2 > 100" w p lt 1 pt 6 ps 1.5

