#!/usr/bin/env python

"""
map_uncertainty.py
Determine 3-sigma uncertainties from a 1-dimensional maps of chi^2.

"""

__author__ = "Miroslav Broz (miroslav.broz@email.cz)"
__version__ = "Mar 9th 2016"

def interp(x1,y1,x2,y2,x):
    return y1+(y2-y1)*(x-x1)/(x2-x1)

import re
from chi2 import *

fin = open("chi2.in", "r")
j = 0
n = 26
x_param = []
for line in fin.readlines():
    if not re.match("^#", line) and len(line) > 1:
        l = line.split()
        for i in range(0,len(l)):
            j += 1
            if j > 1 and j <= n+1:
                x_param.append(l[i])
        if j > 26:
            break
fin.close()

x_param = map(lambda x: float(x), x_param)

str_ = [ \
    'm_1', \
    'm_2', \
    'm_3', \
    'P_1', \
    'e_1', \
    'i_1', \
    'Omega_1', \
    'omega_1', \
    'M_1', \
    'P_2', \
    'e_2', \
    'i_2', \
    'Omega_2', \
    'omega_2', \
    'M_2', \
    'T_1', \
    'T_2', \
    'T_3', \
    'logg_1', \
    'logg_2', \
    'logg_3', \
    'vrot_1', \
    'vrot_2', \
    'vrot_3', \
    'gamma', \
    'd', \
    ]


lst = [ 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25 ]

y0 = chi2_1sigma

print "# number & parameter & xleft & xcenter & xright & xcenter - 1sigma + 1sigma & ycenter = chi^2 minimum & y0 = chi^2 level corresponding to 1sigma"

for i in lst:

    filename = "chi2_func.tmp" + str(i)
    try:
        f = open(filename, "r")
    except IOError as ex:
        print "File '" + filename + "' does not exist!"
    else:

        lines = f.readlines()
        f.close()
 
        x = []
        y = []
        for line in lines:
            l = line.split()
            x.append(float(l[i]))
            y.append(float(l[-1]))
 
        xleft = 0.0
        xcenter = 0.0
        xright = 0.0
        ycenter = 1.e38
 
#        for j in xrange(1,len(x)-1):
        for j in xrange(1,len(x)-1):
 
            if y[j-1] >= y0 and y[j] <= y0:
                xleft = interp(y[j-1], x[j-1], y[j], x[j], y0)
                ycenter = 1.e38
                #print 'xleft = ', xleft
 
            if y[j-1] >= y[j] and y[j+1] >= y[j] and y[j] <= y0 and y[j] < ycenter:
                xcenter = x[j]
                ycenter = y[j]
                #print 'xcenter = ', xcenter
 
            if y[j-1] <= y0 and y[j] >= y0:
                xright = interp(y[j-1], x[j-1], y[j], x[j], y0)
                #print 'xright = ', xright

                xcenter2 = xcenter
                if abs(xcenter-x_param[i]) < 0.1:
                    xcenter2 = x_param[i]
                if abs(xcenter-(x_param[i]+360.)) < 0.1:
                    xcenter2 = x_param[i]+360.

                print "%3d  %10s    %12.7f  %12.7f  %12.7f    %12.7f - %12.7f + %12.7f    %12.7f  %12.7f" % (i, str_[i], xleft, xcenter, xright, xcenter2, xcenter2-xleft, xright-xcenter2, ycenter, y0)
 
        print ""



